<?PHP
/* Structure of array:
0: name of element
1: mandatory? (y or n)
2: format (eg. text/utf8
3: allowed values (eg. "m", "cm", ...)
4: dependent fields
5: remarks
*/
require __DIR__ . "/../translation-importer/$lang/csvxml-overview.php";

require __DIR__ . "/langfiles/$lang/object_basis.php";
require __DIR__ . "/langfiles/$lang/object.php";
require __DIR__ . "/langfiles/$lang/quality.php";

require __DIR__ . "/langfiles/$lang/museum.php";
require __DIR__ . "/langfiles/$lang/place.php";
require __DIR__ . "/langfiles/$lang/settings.php";

$availableFields = [

    $csvxml_overview['object_base_data'] => [
        "inventory_number" => [
            "required"            => true,
            "format"              => 'text/utf8',
            "allowedValues"       => 'freetext',
            "dependsOn"           => [],
            "remark"              => 'Only unique values allowed',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "object_type" => [
            "required"            => true,
            "format"              => 'text/utf8',
            "allowedValues"       => 'freetext',
            "dependsOn"           => [],
            "remark"              => 'Keep it short! Field is needed to create valid LIDO from museum-digital entries',
            "name_human_readable" => $object_basis['object_type'],
            "explica"             => $object_basis['oart_explica'],
        ],
        "object_title" => [
            "required"            => true,
            "format"              => 'text/utf8',
            "allowedValues"       => 'freetext',
            "dependsOn"           => [],
            "remark"              => 'Best is not to repeat the title again and again for many objects, e.g. vase, vase, vase ... better: Green vase, Blue vase, Yellow vase, ...',
            "name_human_readable" => $object_basis['object_name'],
            "explica"             => $object_basis['oname_explica'],
        ],
        "object_description" => [
            "required"            => true,
            "format"              => 'text/utf8',
            "allowedValues"       => 'freetext',
            "dependsOn"           => [],
            "remark"              => 'A good description of the objects is fundamental to make the objects searchable in the internet',
            "name_human_readable" => $object_basis['description'],
            "explica"             => $object_basis['obesch_explica'],
        ],
        "object_material_technique" => [
            "required"            => false,
            "format"              => 'text/utf8',
            "allowedValues"       => 'freetext',
            "dependsOn"           => [],
            "remark"              => 'This is a cummulative field for material and technique. It is also possible to additionally save the information separate in the fields: <i>material_separate</i> and <i>technique_separate</i>',
            "name_human_readable" => $object_basis['mattech'],
            "explica"             => $object_basis['mattech_explica'],
        ],
        "object_dimensions" => [
            "required"            => false,
            "format"              => 'text/utf8',
            "allowedValues"       => 'freetext',
            "dependsOn"           => [],
            "remark"              => 'This is a cummulative field for dimensions (values and units). It is also possible to additionally save the information separate. See the block: <i>separate dimensions</i>',
            "name_human_readable" => $object_basis['measurements'],
            "explica"             => $object_basis['ausmass_explica'],
        ],
        "object_publication" => [
            "required"            => false,
            "format"              => 'text/utf8',
            "allowedValues"       => 'One letter only, y or n',
            "dependsOn"           => [],
            "remark"              => 'Shall the object be visible directly after import?',
            "name_human_readable" => $objekt['visibility'],
            "explica"             => '',
        ],
        "institution_name" => [
            "required"            => false,
            "format"              => 'text/utf8',
            "allowedValues"       => 'freetext',
            "dependsOn"           => [],
            "remark"              => 'If name of institution is given it has to be exactly the same as already known in museum-digital',
            "name_human_readable" => $museum['museum_name'],
            "explica"             => $museum['musnam_explica'],
        ],
    ],
    "other_object_title" => [
        "other_object_title" => [
            "required"            => false,
            "format"              => 'text/utf8',
            "allowedValues"       => 'freetext',
            "dependsOn"           => 'object_other_title_kind_of',
            "remark"              => 'If the field <i>object_other_title</i> is used. It has to be specified where this alternative title is used. Specification should be done within the field: <i>object_other_title_kind_of</i>',
            "name_human_readable" => 'Weitere Objektbezeichnung',
            "explica"             => '',
        ],
        "object_other_title_kind_of" => [
            "required"            => false,
            "format"              => 'text/utf8',
            "allowedValues"       => 'de: "Wissenschaft", "Alltagssprache", "Umgangssprache", "Dialekt"<br>hu: "Tudományos", "Köznyelvi", "Nyelvjárás"',
            "dependsOn"           => 'object_other_title',
            "remark"              => 'This field has to be used togehter with <i>object_other_title</i>',
            "name_human_readable" => 'Weitere Objektbezeichnung, in: ',
            "explica"             => '',
        ],

        "detailed_description" => [
            "required"            => false,
            "allowedValues"       => 'freetext',
            "dependsOn"           => ['detailed_description_md and detailed_description_extern'],
            "remark"              => 'If <i>detailed_desription</i> is made available for an object, <i>detailed_description_md</i> and <i>detailed_description_extern</i> have to have values too',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "detailed_description_md" => [
            "required"            => false,
            "allowedValues"       => '"y","n"',
            "dependsOn"           => ['detailed_description and detailed_description_extern'],
            "remark"              => 'Shall detailed description be visible at museum-digital? If <i>detailed_desription</i> is available for an object, <i>detailed_description_md</i> and <i>detailed_description_extern</i> have to have values too',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "detailed_description_extern" => [
            "required"            => false,
            "allowedValues"       => '"y","n"',
            "dependsOn"           => ['detailed_description_md and detailed_description'],
            "remark"              => 'Shall later exports from museum-digital include the detailed_description?</br>If <i>detailed_desription</i> is available for an object, <i>detailed_description_md</i> and <i>detailed_description_extern</i> have to have values too',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "inscription" => [
            "required"            => false,
            "allowedValues"       => 'freetext',
            "dependsOn"           => ['inscription_md and inscription_extern'],
            "remark"              => 'If <i>inscription</i> is made available for an object, <i>inscription_md></i> and <i>inscription_extern</i> have to have values too',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "inscription_md" => [
            "required"            => false,
            "allowedValues"       => '"y","n"',
            "dependsOn"           => ['inscription_md and inscription_extern'],
            "remark"              => 'Shall a given inscription be displayed at museum-digital? If <i>inscription</i> is available for an object, <i>inscription_md></i> and <i>inscription_extern</i> have to have values too',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "inscription_extern" => [
            "required"            => false,
            "allowedValues"       => '"y","n"',
            "dependsOn"           => ['inscription_md and inscription_extern'],
            "remark"              => 'Shall later exports from museum-digital inlude inscription? If <i>inscription</i> is available for an object, <i>inscription_md></i> and <i>inscription_extern</i> have to have values too',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "material_separate" => [
            "required"            => false,
            "allowedValues"       => 'freetext',
            "remark"              => 'Additional to collecting material and technique in a combined field (see above), the material(s) can be given here separately',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "technique_separate" => [
            "required"            => false,
            "allowedValues"       => 'freetext',
            "remark"              => 'Additional to collecting material and technique in a combined field (see above), the technique(s) can be given here separately',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "dimensions_separate_length_value" => [
            "required"            => false,
            "allowedValues"       => 'number',
            "dependsOn"           => ['dimensions_separate_length_unit, dimensions_separate_show_md, dimensions_separate_show_extern'],
            "remark"              => 'If a separated value is given an entry for the respective unit is necessary. If a separated dimension entry is given, <i>dimensions_separate_show_md</i> and <i>dimensions_separate_show_extern</i> need to be filled in, too.',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "dimensions_separate_length_unit" => [
            "required"            => false,
            "allowedValues"       => '"m","dm","cm","mm"',
            "dependsOn"           => ['dimensions_separate_length_value, dimensions_separate_show_md, dimensions_separate_show_extern'],
            "remark"              => 'If a separated value is given an entry for the respective unit is necessary. If a separated dimension entry is given, <i>dimensions_separate_show_md</i> and <i>dimensions_separate_show_extern</i> need to be filled in, too.',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "dimensions_separate_width_value" => [
            "required"            => false,
            "allowedValues"       => 'number',
            "dependsOn"           => ['dimensions_separate_width_unit, dimensions_separate_show_md, dimensions_separate_show_extern'],
            "remark"              => 'If a separated value is given an entry for the respective unit is necessary. If a separated dimension entry is given, <i>dimensions_separate_show_md</i> and <i>dimensions_separate_show_extern</i> need to be filled in, too.',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "dimensions_separate_width_unit" => [
            "required"            => false,
            "allowedValues"       => '"m","dm","cm","mm"',
            "dependsOn"           => ['dimensions_separate_width_value, dimensions_separate_show_md, dimensions_separate_show_extern'],
            "remark"              => 'If a separated value is given an entry for the respective unit is necessary. If a separated dimension entry is given, <i>dimensions_separate_show_md</i> and <i>dimensions_separate_show_extern</i> need to be filled in, too.',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "dimensions_separate_height_value" => [
            "required"            => false,
            "allowedValues"       => 'number',
            "dependsOn"           => ['dimensions_separate_height_unit, dimensions_separate_show_md, dimensions_separate_show_extern'],
            "remark"              => 'If a separated value is given an entry for the respective unit is necessary. If a separated dimension entry is given, <i>dimensions_separate_show_md</i> and <i>dimensions_separate_show_extern</i> need to be filled in, too.',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "dimensions_separate_height_unit" => [
            "required"            => false,
            "allowedValues"       => '"m","dm","cm","mm"',
            "dependsOn"           => ['dimensions_separate_height_value, dimensions_separate_show_md, dimensions_separate_show_extern'],
            "remark"              => 'If a separated value is given an entry for the respective unit is necessary. If a separated dimension entry is given, <i>dimensions_separate_show_md</i> and <i>dimensions_separate_show_extern</i> need to be filled in, too.',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "dimensions_separate_weight_value" => [
            "required"            => false,
            "allowedValues"       => 'number',
            "dependsOn"           => ['dimensions_separate_weight_unit, dimensions_separate_show_md, dimensions_separate_show_extern'],
            "remark"              => 'If a separated value is given an entry for the respective unit is necessary. If a separated dimension entry is given, <i>dimensions_separate_show_md</i> and <i>dimensions_separate_show_extern</i> need to be filled in, too.',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "dimensions_separate_weight_unit" => [
            "required"            => false,
            "allowedValues"       => '"m","dm","cm","mm"',
            "dependsOn"           => ['dimensions_separate_width_value, dimensions_separate_show_md, dimensions_separate_show_extern'],
            "remark"              => 'If a separated value is given an entry for the respective unit is necessary. If a separated dimension entry is given, <i>dimensions_separate_show_md</i> and <i>dimensions_separate_show_extern</i> need to be filled in, too.',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "dimensions_separate_diameter_value" => [
            "required"            => false,
            "allowedValues"       => 'number',
            "dependsOn"           => ['dimensions_separate_diameter_unit, dimensions_separate_show_md, dimensions_separate_show_extern'],
            "remark"              => 'If a separated value is given an entry for the respective unit is necessary. If a separated dimension entry is given, <i>dimensions_separate_show_md</i> and <i>dimensions_separate_show_extern</i> need to be filled in, too.',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "dimensions_separate_diameter_unit" => [
            "required"            => false,
            "allowedValues"       => '"m","dm","cm","mm"',
            "dependsOn"           => ['dimensions_separate_diameter_value, dimensions_separate_show_md, dimensions_separate_show_extern'],
            "remark"              => 'If a separated value is given an entry for the respective unit is necessary. If a separated dimension entry is given, <i>dimensions_separate_show_md</i> and <i>dimensions_separate_show_extern</i> need to be filled in, too.',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "dimensions_separate_wall_thickness_value" => [
            "required"            => false,
            "allowedValues"       => 'number',
            "dependsOn"           => ['dimensions_separate_thickness_unit, dimensions_separate_show_md, dimensions_separate_show_extern'],
            "remark"              => 'If a separated value is given an entry for the respective unit is necessary. If a separated dimension entry is given, <i>dimensions_separate_show_md</i> and <i>dimensions_separate_show_extern</i> need to be filled in, too.',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "dimensions_separate_wall_thickness_unit" => [
            "required"            => false,
            "allowedValues"       => '"m","dm","cm","mm"',
            "dependsOn"           => ['dimensions_separate_thickness_value, dimensions_separate_show_md, dimensions_separate_show_extern'],
            "remark"              => 'If a separated value is given an entry for the respective unit is necessary. If a separated dimension entry is given, <i>dimensions_separate_show_md</i> and <i>dimensions_separate_show_extern</i> need to be filled in, too.',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "dimensions_separate_show_md" => [
            "required"            => false,
            "allowedValues"       => '"y","n"',
            "dependsOn"           => ['Any field named dimensions_separate ...'],
            "remark"              => 'If one or more separate dimension-value (and -unit) is given it has to be specified if the separated entries should be made visible at museum-digital',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "dimensions_separate_show_extern" => [
            "required"            => false,
            "allowedValues"       => '"y","n"',
            "dependsOn"           => ['Any field named dimensions_separate ...'],
            "remark"              => 'If one or more separate dimension-value (and -unit) is given it has to be specified if the separated entries should be included in a later export from museum-digital',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "number_of_pieces" => [
            "required"            => false,
            "allowedValues"       => 'number',
            "remark"              => 'Only to be given if more than one copies of an object are available and catalogued with the same inventory number',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "number_of_pages" => [
            "required"            => false,
            "allowedValues"       => 'number',
            "remark"              => 'Only to be given for books (etc.)',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "comparable_objects_other_museums" => [
            "required"            => false,
            "allowedValues"       => 'freetext',
            "dependsOn"           => ['comparable_objects_other_museums_show_md, comparable_objects_other_museums_show_extern'],
            "remark"              => 'Name of other museum and if available the inventory number of the respective object. If <i>comparable_objects_other_museums</i> is given <i>comparable_objects_other_museums_show_md</i> and <i>comparable_objects_other_museums_show_extern</i> have to be given too',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "comparable_objects_other_museums_show_md" => [
            "required"            => false,
            "allowedValues"       => '"y","n"',
            "dependsOn"           => ['comparable_objects_other_museums'],
            "remark"              => 'Necessary if <i>comparable_objects_other_museums</i> is given. Should the information about comparable objects be displayed at museum-digital?',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "comparable_objects_other_museums_show_extern" => [
            "required"            => false,
            "allowedValues"       => '"y","n"',
            "dependsOn"           => ['comparable_objects_other_museums'],
            "remark"              => 'Necessary if <i>comparable_objects_other_museums</i> is given. Should the information about comparable objects be part of later exports from museum-digital?',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "closer_location" => [
            "required"            => false,
            "allowedValues"       => 'freetext',
            "dependsOn"           => ['closer_location_as'],
            "remark"              => 'A place in a special relation to the object. The kind of relation has to specified in <i>closer_location_as</i>',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "closer_location_as" => [
            "required"            => false,
            "allowedValues"       => 'de: "Aufnahmeort", "Fundort", "Früherer Ort"&#10;hu: "Felvétel késztésének helye","Lelőhely","Történelmi elnevezés"',
            "dependsOn"           => ['closer_location'],
            "remark"              => 'A place in a special relation to the object can be given in <i>closer_location</i>. Here the kind of relation between object and place has to specified',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "entry_number" => [
            "required"            => false,
            "allowedValues"       => 'freetext',
            "remark"              => 'The entry number of the object if available',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "other_inventory_number" => [
            "required"            => false,
            "allowedValues"       => 'freetext',
            "remark"              => 'All other inventory numbers (older ones presumably) in one field',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "subject_group" => [
            "required"            => false,
            "allowedValues"       => 'freetext',
            "remark"              => 'If the object is part of an subject group this information should be given here',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "systematic" => [
            "required"            => false,
            "allowedValues"       => 'freetext',
            "remark"              => 'If the object is put into a museum-systematic the place it has there',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "bundle" => [
            "required"            => false,
            "allowedValues"       => 'freetext',
            "remark"              => 'The bundle the object belongs to',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "part_of" => [
            "required"            => false,
            "allowedValues"       => 'freetext',
            "remark"              => 'If the object is part of something it can be given here',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "inclusion_when" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "inclusion_kind_of" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "inclusion_who" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "inclusion_where" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "registration_first_who" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "registration_first_when" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "owner_previous" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "object_history" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "bought_for" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "bought_for_currency" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "worth_determiner" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "worth_when" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "worth_value" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "worth_unit" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "worth_incurance_determiner" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "worth_incurance_when" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "worth_insurance_value" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "worth_insurance_unit" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "state" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "restauration" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "abode_actual" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "abode_regular" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "exhibition" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "on_loan_to" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "on_loan_contact" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "on_loan_when" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "on_loan_insurance_value" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "on_loan_annotation" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "copyright" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "rights_of_use" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "rights_annotation" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "remarks_short" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "remarks_long" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "images_in_museum" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "documents_in_museum" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "link_url1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "link_show1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "link_url2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "link_show2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "literature_author1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "literature_year1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "literature_title1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "literature_place1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "literature_abbreviation1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "literature_gnd1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "literature_isbn1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "literature_signature1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "literature_online1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "literature_annotation1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "literature_inlit1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "literature_author2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "literature_year2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "literature_title2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "literature_place2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "literature_abbreviation2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "literature_gnd2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "literature_isbn2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "literature_signature2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "literature_online2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "literature_annotation2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "literature_inlit2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "object_group_name1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "object_group_description1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "object_group_show1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "object_group_name2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "object_group_description2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "object_group_show2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "object_group_name3" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "object_group_description3" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "object_group_show3" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "object_group_name4" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "object_group_description4" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "object_group_show4" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "object_group_name5" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "object_group_description5" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "object_group_show5" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "tag1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "tag2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "tag3" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "tag4" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "tag5" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "tag6" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "tag7" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "tag8" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "tag9" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "tag10" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "related_place1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "related_place_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "related_place2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "related_place_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "related_actor1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "related_actor_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "related_actor2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "related_actor_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "related_time1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "related_time_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "related_time2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "related_time_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_name1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_description1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_owner1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_creator1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_rights1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_visible1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_main1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_name2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_description2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_owner2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_creator2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_rights2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_visible2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_main2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_name3" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_description3" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_owner3" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_creator3" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_rights3" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_visible3" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_main3" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_name4" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_description4" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_owner4" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_creator4" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_rights4" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_visible4" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_main4" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_name5" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_description5" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_owner5" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_creator5" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_rights5" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_visible5" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_main5" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_name6" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_description6" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_owner6" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_creator6" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_rights6" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_visible6" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_main6" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_name7" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_description7" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_owner7" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_creator7" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_rights7" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_visible7" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_main7" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_name8" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_description8" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_owner8" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_creator8" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_rights8" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_visible8" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_main8" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_name9" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_description9" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_owner9" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_creator9" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_rights9" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_visible9" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_main9" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_name10" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_description10" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_owner10" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_creator10" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_rights10" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_visible10" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "image_main10" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "resource_media_type1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "resource_fileformat1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "resource_location1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "resource_name1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "resource_description1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "resource_owner1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "resource_creator1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "resource_rights1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "resource_visible1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "resource_media_type2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "resource_fileformat2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "resource_location2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "resource_name2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "resource_description2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "resource_owner2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "resource_creator2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "resource_rights2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "resource_visible2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "production_when1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "production_when_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "production_who1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "production_who_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "production_where1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "production_where_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "production_annotation1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "production_when2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "production_when_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "production_who2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "production_who_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "production_where2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "production_where_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "production_annotation2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "finding_when1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "finding_when_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "finding_who1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "finding_who_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "finding_where1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "finding_where_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "finding_annotation1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "finding_when2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "finding_when_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "finding_who2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "finding_who_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "finding_where2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "finding_where_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "finding_annotation2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "publication_when1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "publication_when_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "publication_who1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "publication_who_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "publication_where1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "publication_where_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "publication_annotation1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "publication_when2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "publication_when_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "publication_who2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "publication_who_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "publication_where2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "publication_where_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "publication_annotation2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "template_creation_when1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "template_creation_when_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "template_creation_who1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "template_creation_who_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "template_creation_where1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "template_creation_where_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "template_creation_annotation1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "template_creation_when2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "template_creation_when_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "template_creation_who2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "template_creation_who_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "template_creation_where2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "template_creation_where_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "template_creation_annotation2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "was_depicted_who1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "was_depicted_who_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "was_depicted_who2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "was_depicted_who_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "was_depicted_place1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "was_depicted_place_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "was_depicted_place2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "was_depicted_place_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "was_used_when1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "was_used_when_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "was_used_who1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "was_used_who_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "was_used_where1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "was_used_where_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "was_used_annotation1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "was_used_when2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "was_used_when_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "was_used_who2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "was_used_who_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "was_used_where2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "was_used_where_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "was_used_annotation2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "written_when1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "written_when_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "written_who1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "written_who_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "written_where1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "written_where_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "written_annotation1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "written_when2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "written_when_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "written_who2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "written_who_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "written_where2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "written_where_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "written_annotation2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "collected_when1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "collected_when_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "collected_who1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "collected_who_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "collected_where1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "collected_where_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "collected_annotation1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "collected_when2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "collected_when_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "collected_who2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "collected_who_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "collected_where2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "collected_where_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "collected_annotation2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "painted_when1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "painted_when_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "painted_who1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "painted_who_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "painted_where1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "painted_where_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "painted_annotation1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "painted_when2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "painted_when_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "painted_who2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "painted_who_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "painted_where2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "painted_where_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "painted_annotation2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "taken_when1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "taken_when_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "taken_who1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "taken_who_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "taken_where1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "taken_where_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "taken_annotation1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "taken_when2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "taken_when_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "taken_who2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "taken_who_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "taken_where2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "taken_where_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "taken_annotation2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "received_when1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "received_when_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "received_who1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "received_who_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "received_where1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "received_where_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "received_annotation1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "received_when2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "received_when_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "received_who2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "received_who_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "received_where2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "received_where_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "received_annotation2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "printing_plate_produced_when1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "printing_plate_produced_when_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "printing_plate_produced_who1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "printing_plate_produced_who_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "printing_plate_produced_where1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "printing_plate_produced_where_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "printing_plate_produced_annotation1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "printing_plate_produced_when2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "printing_plate_produced_when_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "printing_plate_produced_who2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "printing_plate_produced_who_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "printing_plate_produced_where2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "printing_plate_produced_where_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "printing_plate_produced_annotation2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "sent_when1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "sent_when_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "sent_who1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "sent_who_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "sent_where1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "sent_where_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "sent_annotation1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "sent_when2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "sent_when_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "sent_who2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "sent_who_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "sent_where2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "sent_where_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "sent_annotation2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "issued_when1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "issued_when_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "issued_who1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "issued_who_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "issued_where1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "issued_where_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "issued_annotation1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "issued_when2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "issued_when_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "issued_who2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "issued_who_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "issued_where2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "issued_where_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "issued_annotation2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "signed_when1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "signed_when_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "signed_who1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "signed_who_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "signed_where1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "signed_where_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "signed_annotation1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "signed_when2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "signed_when_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "signed_who2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "signed_who_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "signed_where2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "signed_where_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "signed_annotation2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "type_described_when1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "type_described_when_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "type_described_who1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "type_described_who_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "type_described_where1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "type_described_where_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "type_described_annotation1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "type_described_when2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "type_described_when_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "type_described_who2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "type_described_who_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "type_described_where2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "type_described_where_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "type_described_annotation2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "drawn_when1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "drawn_when_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "drawn_who1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "drawn_who_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "drawn_where1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "drawn_where_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "drawn_annotation1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "drawn_when2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "drawn_when_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "drawn_who2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "drawn_who_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "drawn_where2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "drawn_where_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "drawn_annotation2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "copied_when1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "copied_when_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "copied_who1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "copied_who_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "copied_where1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "copied_where_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "copied_annotation1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "copied_when2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "copied_when_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "copied_who2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "copied_who_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "copied_where2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "copied_where_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "copied_annotation2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "has_lived_when1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "has_lived_when_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "has_lived_where1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "has_lived_where_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "has_lived_annotation1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "has_lived_when2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "has_lived_when_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "has_lived_where2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "has_lived_where_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "has_lived_annotation2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "commissioned_when1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "commissioned_when_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "commissioned_who1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "commissioned_who_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "commissioned_where1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "commissioned_where_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "commissioned_annotation1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "commissioned_when2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "commissioned_when_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "commissioned_who2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "commissioned_who_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "commissioned_where2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "commissioned_where_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "commissioned_annotation2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "printed_when1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "printed_when_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "printed_who1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "printed_who_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "printed_where1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "printed_where_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "printed_annotation1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "printed_when2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "printed_when_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "printed_who2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "printed_who_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "printed_where2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "printed_where_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "printed_annotation2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "spoken_when1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "spoken_when_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "spoken_who1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "spoken_who_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "spoken_where1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "spoken_where_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "spoken_annotation1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "spoken_when2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "spoken_when_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "spoken_who2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "spoken_who_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "spoken_where2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "spoken_where_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "spoken_annotation2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "sung_when1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "sung_when_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "sung_who1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "sung_who_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "sung_where1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "sung_where_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "sung_annotation1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "sung_when2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "sung_when_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "sung_who2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "sung_who_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "sung_where2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "sung_where_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "sung_annotation2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "decor_designed_when1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "decor_designed_when_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "decor_designed_who1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "decor_designed_who_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "decor_designed_where1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "decor_designed_where_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "decor_designed_annotation1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "decor_designed_when2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "decor_designed_when_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "decor_designed_who2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "decor_designed_who_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "decor_designed_where2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "decor_designed_where_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "decor_designed_annotation2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "form_designed_when1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "form_designed_when_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "form_designed_who1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "form_designed_who_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "form_designed_where1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "form_designed_where_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "form_designed_annotation1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "form_designed_when2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "form_designed_when_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "form_designed_who2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "form_designed_who_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "form_designed_where2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "form_designed_where_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "form_designed_annotation2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "modelled_when1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "modelled_when_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "modelled_who1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "modelled_who_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "modelled_where1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "modelled_where_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "modelled_annotation1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "modelled_when2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "modelled_when_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "modelled_who2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "modelled_who_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "modelled_where2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "modelled_where_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "modelled_annotation2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "signed_when1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "signed_when_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "signed_who1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "signed_who_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "signed_where1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "signed_where_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "signed_annotation1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "signed_when2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "signed_when_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "signed_who2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "signed_who_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "signed_where2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "signed_where_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "signed_annotation2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "was_mentioned_when1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "was_mentioned_when_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "was_mentioned_who1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "was_mentioned_who_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "was_mentioned_where1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "was_mentioned_where_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "was_mentioned_annotation1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "was_mentioned_when2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "was_mentioned_when_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "was_mentioned_who2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "was_mentioned_who_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "was_mentioned_where2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "was_mentioned_where_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "was_mentioned_annotation2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "buried_when1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "buried_when_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "buried_who1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "buried_who_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "buried_where1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "buried_where_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "buried_annotation1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "buried_when2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "buried_when_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "buried_who2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "buried_who_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "buried_where2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "buried_where_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "buried_annotation2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "intellectual_creation_when1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "intellectual_creation_when_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "intellectual_creation_who1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "intellectual_creation_who_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "intellectual_creation_where1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "intellectual_creation_where_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "intellectual_creation_annotation1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "intellectual_creation_when2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "intellectual_creation_when_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "intellectual_creation_who2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "intellectual_creation_who_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "intellectual_creation_where2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "intellectual_creation_where_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "intellectual_creation_annotation2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "painted_on_when1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "painted_on_when_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "painted_on_who1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "painted_on_who_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "painted_on_where1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "painted_on_where_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "painted_on_annotation1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "painted_on_when2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "painted_on_when_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "painted_on_who2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "painted_on_who_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "painted_on_where2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "painted_on_where_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "painted_on_annotation2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "illustrated_when1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "illustrated_when_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "illustrated_who1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "illustrated_who_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "illustrated_where1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "illustrated_where_sure1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "illustrated_annotation1" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "illustrated_when2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "illustrated_when_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "illustrated_who2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "illustrated_who_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "illustrated_where2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "illustrated_where_sure2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],
        "illustrated_annotation2" => [
            "required"            => false,
            "allowedValues"       => '',
            "remark"              => '',
            "name_human_readable" => $object_basis['inventory_number'],
            "explica"             => $object_basis['inv_explica'],
        ],

    ],
];


/*
 * Repeat fields
 */

// Collection names

for ($i = 1; $i <= 2; $i++) {

    $availableFields[$csvxml_overview['object_base_data']]["collection_name{$i}"] = [
        "category"            => "basic",
        "required"            => false,
        "format"              => 'text/utf8',
        "allowedValues"       => 'freetext',
        "dependsOn"           => [],
        "remark"              => 'Use if object belongs to a collection. If collection is already in museum-digital, please use exactly the same name',
        "name_human_readable" => $museum['museum_name'],
        "explica"             => $museum['musnam_explica'],
    ];

}

return;

$allowed = array(
array ('object_other_title','n','text/utf8','freetext','object_other_title_kind_of','If the field <i>object_other_title</i> is used. It has to be specified where this alternative title is used. Specification should be done within the field: <i>object_other_title_kind_of</i>'),
array ('object_other_title_kind_of','n','text/utf8','de: "Wissenschaft", "Alltagssprache", "Umgangssprache", "Dialekt"<br>hu: "Tudományos", "Köznyelvi", "Nyelvjárás"', 'object_other_title', 'This field has to be used togehter with <i>object_other_title</i>'),
array ('detailed_description','n','text/utf8','freetext','detailed_description_md and detailed_description_extern','If <i>detailed_desription</i> is made available for an object, <i>detailed_description_md</i> and <i>detailed_description_extern</i> have to have values too'),
array ('detailed_description_md','n','One letter only','"y","n"','detailed_description and detailed_description_extern','Shall detailed description be visible at museum-digital? If <i>detailed_desription</i> is available for an object, <i>detailed_description_md</i> and <i>detailed_description_extern</i> have to have values too'),
array ('detailed_description_extern','n','One letter only','"y","n"','detailed_description_md and detailed_description','Shall later exports from museum-digital include the detailed_description?</br>If <i>detailed_desription</i> is available for an object, <i>detailed_description_md</i> and <i>detailed_description_extern</i> have to have values too'),
array ('inscription','n','text/utf8','freetext','inscription_md and inscription_extern','If <i>inscription</i> is made available for an object, <i>inscription_md></i> and <i>inscription_extern</i> have to have values too'),
array ('inscription_md','n','One letter only','"y","n"','inscription_md and inscription_extern','Shall a given inscription be displayed at museum-digital? If <i>inscription</i> is available for an object, <i>inscription_md></i> and <i>inscription_extern</i> have to have values too'),
array ('inscription_extern','n','One letter only','"y","n"','inscription_md and inscription_extern','Shall later exports from museum-digital inlude inscription? If <i>inscription</i> is available for an object, <i>inscription_md></i> and <i>inscription_extern</i> have to have values too'),
array ('material_separate','n','text/utf8','freetext','none','Additional to collecting material and technique in a combined field (see above), the material(s) can be given here separately'),
array ('technique_separate','n','text/utf8','freetext','none', 'Additional to collecting material and technique in a combined field (see above), the technique(s) can be given here separately'),
array ('dimensions_separate_length_value','n','text/utf8','number','dimensions_separate_length_unit, dimensions_separate_show_md, dimensions_separate_show_extern','If a separated value is given an entry for the respective unit is necessary. If a separated dimension entry is given, <i>dimensions_separate_show_md</i> and <i>dimensions_separate_show_extern</i> need to be filled in, too.'),
array ('dimensions_separate_length_unit','n','text/utf8','"m","dm","cm","mm"','dimensions_separate_length_value, dimensions_separate_show_md, dimensions_separate_show_extern','If a separated value is given an entry for the respective unit is necessary. If a separated dimension entry is given, <i>dimensions_separate_show_md</i> and <i>dimensions_separate_show_extern</i> need to be filled in, too.'),
array ('dimensions_separate_width_value', 'n', 'text/utf8', 'number','dimensions_separate_width_unit, dimensions_separate_show_md, dimensions_separate_show_extern','If a separated value is given an entry for the respective unit is necessary. If a separated dimension entry is given, <i>dimensions_separate_show_md</i> and <i>dimensions_separate_show_extern</i> need to be filled in, too.'),
array ('dimensions_separate_width_unit', 'n', 'text/utf8', '"m","dm","cm","mm"','dimensions_separate_width_value, dimensions_separate_show_md, dimensions_separate_show_extern','If a separated value is given an entry for the respective unit is necessary. If a separated dimension entry is given, <i>dimensions_separate_show_md</i> and <i>dimensions_separate_show_extern</i> need to be filled in, too.'),
array ('dimensions_separate_height_value', 'n', 'text/utf8', 'number','dimensions_separate_height_unit, dimensions_separate_show_md, dimensions_separate_show_extern','If a separated value is given an entry for the respective unit is necessary. If a separated dimension entry is given, <i>dimensions_separate_show_md</i> and <i>dimensions_separate_show_extern</i> need to be filled in, too.'),
array ('dimensions_separate_height_unit', 'n', 'text/utf8', '"m","dm","cm","mm"','dimensions_separate_height_value, dimensions_separate_show_md, dimensions_separate_show_extern','If a separated value is given an entry for the respective unit is necessary. If a separated dimension entry is given, <i>dimensions_separate_show_md</i> and <i>dimensions_separate_show_extern</i> need to be filled in, too.'),
array ('dimensions_separate_weight_value', 'n', 'text/utf8','number','dimensions_separate_weight_unit, dimensions_separate_show_md, dimensions_separate_show_extern','If a separated value is given an entry for the respective unit is necessary. If a separated dimension entry is given, <i>dimensions_separate_show_md</i> and <i>dimensions_separate_show_extern</i> need to be filled in, too.'),
array ('dimensions_separate_weight_unit', 'n', 'text/utf8', '"m","dm","cm","mm"','dimensions_separate_width_value, dimensions_separate_show_md, dimensions_separate_show_extern','If a separated value is given an entry for the respective unit is necessary. If a separated dimension entry is given, <i>dimensions_separate_show_md</i> and <i>dimensions_separate_show_extern</i> need to be filled in, too.'),
array ('dimensions_separate_diameter_value', 'n', 'text/utf8', 'number','dimensions_separate_diameter_unit, dimensions_separate_show_md, dimensions_separate_show_extern','If a separated value is given an entry for the respective unit is necessary. If a separated dimension entry is given, <i>dimensions_separate_show_md</i> and <i>dimensions_separate_show_extern</i> need to be filled in, too.'),
array ('dimensions_separate_diameter_unit', 'n', 'text/utf8', '"m","dm","cm","mm"','dimensions_separate_diameter_value, dimensions_separate_show_md, dimensions_separate_show_extern','If a separated value is given an entry for the respective unit is necessary. If a separated dimension entry is given, <i>dimensions_separate_show_md</i> and <i>dimensions_separate_show_extern</i> need to be filled in, too.'),
array ('dimensions_separate_wall_thickness_value', 'n', 'text/utf8', 'number','dimensions_separate_thickness_unit, dimensions_separate_show_md, dimensions_separate_show_extern','If a separated value is given an entry for the respective unit is necessary. If a separated dimension entry is given, <i>dimensions_separate_show_md</i> and <i>dimensions_separate_show_extern</i> need to be filled in, too.'),
array ('dimensions_separate_wall_thickness_unit', 'n', 'text/utf8', '"m","dm","cm","mm"','dimensions_separate_thickness_value, dimensions_separate_show_md, dimensions_separate_show_extern','If a separated value is given an entry for the respective unit is necessary. If a separated dimension entry is given, <i>dimensions_separate_show_md</i> and <i>dimensions_separate_show_extern</i> need to be filled in, too.'),
array ('dimensions_separate_show_md', 'n', 'One letter only', '"y","n"','Any field named dimensions_separate ...','If one or more separate dimension-value (and -unit) is given it has to be specified if the separated entries should be made visible at museum-digital'),
array ('dimensions_separate_show_extern', 'n', 'One letter only', '"y","n"','Any field named dimensions_separate ...','If one or more separate dimension-value (and -unit) is given it has to be specified if the separated entries should be included in a later export from museum-digital'),
array ('number_of_pieces', 'n', 'text/utf8','number','none','Only to be given if more than one copies of an object are available and catalogued with the same inventory number'),
array ('number_of_pages', 'n', 'text/utf8', 'number', 'none','Only to be given for books (etc.)'),
array ('comparable_objects_other_museums', 'n', 'text/utf8', 'freetext', 'comparable_objects_other_museums_show_md, comparable_objects_other_museums_show_extern', 'Name of other museum and if available the inventory number of the respective object. If <i>comparable_objects_other_museums</i> is given <i>comparable_objects_other_museums_show_md</i> and <i>comparable_objects_other_museums_show_extern</i> have to be given too'),
array ('comparable_objects_other_museums_show_md', 'n', 'One letter only', '"y","n"', 'comparable_objects_other_museums','Necessary if <i>comparable_objects_other_museums</i> is given. Should the information about comparable objects be displayed at museum-digital?'),
array ('comparable_objects_other_museums_show_extern', 'n', 'One letter only', '"y","n"', 'comparable_objects_other_museums','Necessary if <i>comparable_objects_other_museums</i> is given. Should the information about comparable objects be part of later exports from museum-digital?'),
//array ('other_object_title', 'n', ''),
//array ('other_object_title_in', 'n', ''),
array ('closer_location', 'n', 'text/utf8', 'freetext', 'closer_location_as', 'A place in a special relation to the object. The kind of relation has to specified in <i>closer_location_as</i>'),
array ('closer_location_as', 'n', 'text/utf8', 'de: "Aufnahmeort", "Fundort", "Früherer Ort"&#10;hu: "Felvétel késztésének helye","Lelőhely","Történelmi elnevezés"', 'closer_location', 'A place in a special relation to the object can be given in <i>closer_location</i>. Here the kind of relation between object and place has to specified'),
/* Structure of array:
0: name of element
1: mandatory? (y or n)
2: format (eg. text/utf8
3: allowed values (eg. "m", "cm", ...)
4: dependent fields
5: remarks
*/
array ('entry_number', 'n', 'text/utf8','freetext','none','The entry number of the object if available'),
array ('other_inventory_number', 'n', 'text/utf8','freetext','none','All other inventory numbers (older ones presumably) in one field'),
array ('subject_group', 'n', 'text/utf8','freetext','none','If the object is part of an subject group this information should be given here'),
array ('systematic', 'n', 'text/utf8','freetext','none','If the object is put into a museum-systematic the place it has there'),
array ('bundle', 'n', 'text/utf8','freetext','none','The bundle the object belongs to'),
array ('part_of', 'n', 'text/utf8','freetext','none','If the object is part of something it can be given here'),
array ('inclusion_when', 'n', ''),
array ('inclusion_kind_of', 'n', ''),
array ('inclusion_who', 'n', ''),
array ('inclusion_where', 'n', ''),
array ('registration_first_who', 'n', ''),
array ('registration_first_when', 'n', ''),
array ('owner_previous', 'n', ''),
array ('object_history', 'n', ''),
array ('bought_for', 'n', ''),
array ('bought_for_currency', 'n', ''),
array ('worth_determiner', 'n', ''),
array ('worth_when', 'n', ''),
array ('worth_value', 'n', ''),
array ('worth_unit', 'n', ''),
array ('worth_incurance_determiner', 'n', ''),
array ('worth_incurance_when', 'n', ''),
array ('worth_insurance_value', 'n', ''),
array ('worth_insurance_unit', 'n', ''),
array ('state', 'n', ''),
array ('restauration', 'n', ''),
array ('abode_actual', 'n', ''),
array ('abode_regular', 'n', ''),
array ('exhibition', 'n', ''),
array ('on_loan_to', 'n', ''),
array ('on_loan_contact', 'n', ''),
array ('on_loan_when', 'n', ''),
array ('on_loan_insurance_value', 'n', ''),
array ('on_loan_annotation', 'n', ''),
array ('copyright', 'n', ''),
array ('rights_of_use', 'n', ''),
array ('rights_annotation', 'n', ''),
array ('remarks_short', 'n', ''),
array ('remarks_long', 'n', ''),
array ('images_in_museum', 'n', ''),
array ('documents_in_museum', 'n', ''),
array ('link_url1', 'n', ''),
array ('link_show1', 'n', ''),
array ('link_url2', 'n', ''),
array ('link_show2', 'n', ''),
array ('literature_author1', 'n', ''),
array ('literature_year1', 'n', ''),
array ('literature_title1', 'n', ''),
array ('literature_place1', 'n', ''),
array ('literature_abbreviation1', 'n', ''),
array ('literature_gnd1', 'n', ''),
array ('literature_isbn1', 'n', ''),
array ('literature_signature1', 'n', ''),
array ('literature_online1', 'n', ''),
array ('literature_annotation1', 'n', ''),
array ('literature_inlit1', 'n', ''),
array ('literature_author2', 'n', ''),
array ('literature_year2', 'n', ''),
array ('literature_title2', 'n', ''),
array ('literature_place2', 'n', ''),
array ('literature_abbreviation2', 'n', ''),
array ('literature_gnd2', 'n', ''),
array ('literature_isbn2', 'n', ''),
array ('literature_signature2', 'n', ''),
array ('literature_online2', 'n', ''),
array ('literature_annotation2', 'n', ''),
array ('literature_inlit2', 'n', ''),
array ('object_group_name1', 'n', ''),
array ('object_group_description1', 'n', ''),
array ('object_group_show1', 'n', ''),
array ('object_group_name2', 'n', ''),
array ('object_group_description2', 'n', ''),
array ('object_group_show2', 'n', ''),
array ('object_group_name3', 'n', ''),
array ('object_group_description3', 'n', ''),
array ('object_group_show3', 'n', ''),
array ('object_group_name4', 'n', ''),
array ('object_group_description4', 'n', ''),
array ('object_group_show4', 'n', ''),
array ('object_group_name5', 'n', ''),
array ('object_group_description5', 'n', ''),
array ('object_group_show5', 'n', ''),
array ('tag1', 'n', ''),
array ('tag2', 'n', ''),
array ('tag3', 'n', ''),
array ('tag4', 'n', ''),
array ('tag5', 'n', ''),
array ('tag6', 'n', ''),
array ('tag7', 'n', ''),
array ('tag8', 'n', ''),
array ('tag9', 'n', ''),
array ('tag10', 'n', ''),
array ('related_place1', 'n', ''),
array ('related_place_sure1', 'n', ''),
array ('related_place2', 'n', ''),
array ('related_place_sure2', 'n', ''),
array ('related_actor1', 'n', ''),
array ('related_actor_sure1', 'n', ''),
array ('related_actor2', 'n', ''),
array ('related_actor_sure2', 'n', ''),
array ('related_time1', 'n', ''),
array ('related_time_sure1', 'n', ''),
array ('related_time2', 'n', ''),
array ('related_time_sure2', 'n', ''),
array ('image_name1', 'n', ''),
array ('image_description1', 'n', ''),
array ('image_owner1', 'n', ''),
array ('image_creator1', 'n', ''),
array ('image_rights1', 'n', ''),
array ('image_visible1', 'n', ''),
array ('image_main1', 'n', ''),
array ('image_name2', 'n', ''),
array ('image_description2', 'n', ''),
array ('image_owner2', 'n', ''),
array ('image_creator2', 'n', ''),
array ('image_rights2', 'n', ''),
array ('image_visible2', 'n', ''),
array ('image_main2', 'n', ''),
array ('image_name3', 'n', ''),
array ('image_description3', 'n', ''),
array ('image_owner3', 'n', ''),
array ('image_creator3', 'n', ''),
array ('image_rights3', 'n', ''),
array ('image_visible3', 'n', ''),
array ('image_main3', 'n', ''),
array ('image_name4', 'n', ''),
array ('image_description4', 'n', ''),
array ('image_owner4', 'n', ''),
array ('image_creator4', 'n', ''),
array ('image_rights4', 'n', ''),
array ('image_visible4', 'n', ''),
array ('image_main4', 'n', ''),
array ('image_name5', 'n', ''),
array ('image_description5', 'n', ''),
array ('image_owner5', 'n', ''),
array ('image_creator5', 'n', ''),
array ('image_rights5', 'n', ''),
array ('image_visible5', 'n', ''),
array ('image_main5', 'n', ''),
array ('image_name6', 'n', ''),
array ('image_description6', 'n', ''),
array ('image_owner6', 'n', ''),
array ('image_creator6', 'n', ''),
array ('image_rights6', 'n', ''),
array ('image_visible6', 'n', ''),
array ('image_main6', 'n', ''),
array ('image_name7', 'n', ''),
array ('image_description7', 'n', ''),
array ('image_owner7', 'n', ''),
array ('image_creator7', 'n', ''),
array ('image_rights7', 'n', ''),
array ('image_visible7', 'n', ''),
array ('image_main7', 'n', ''),
array ('image_name8', 'n', ''),
array ('image_description8', 'n', ''),
array ('image_owner8', 'n', ''),
array ('image_creator8', 'n', ''),
array ('image_rights8', 'n', ''),
array ('image_visible8', 'n', ''),
array ('image_main8', 'n', ''),
array ('image_name9', 'n', ''),
array ('image_description9', 'n', ''),
array ('image_owner9', 'n', ''),
array ('image_creator9', 'n', ''),
array ('image_rights9', 'n', ''),
array ('image_visible9', 'n', ''),
array ('image_main9', 'n', ''),
array ('image_name10', 'n', ''),
array ('image_description10', 'n', ''),
array ('image_owner10', 'n', ''),
array ('image_creator10', 'n', ''),
array ('image_rights10', 'n', ''),
array ('image_visible10', 'n', ''),
array ('image_main10', 'n', ''),
array ('resource_media_type1', 'n', ''),
array ('resource_fileformat1', 'n', ''),
array ('resource_location1', 'n', ''),
array ('resource_name1', 'n', ''),
array ('resource_description1', 'n', ''),
array ('resource_owner1', 'n', ''),
array ('resource_creator1', 'n', ''),
array ('resource_rights1', 'n', ''),
array ('resource_visible1', 'n', ''),
array ('resource_media_type2', 'n', ''),
array ('resource_fileformat2', 'n', ''),
array ('resource_location2', 'n', ''),
array ('resource_name2', 'n', ''),
array ('resource_description2', 'n', ''),
array ('resource_owner2', 'n', ''),
array ('resource_creator2', 'n', ''),
array ('resource_rights2', 'n', ''),
array ('resource_visible2', 'n', ''),
array ('production_when1', 'n', ''),
array ('production_when_sure1', 'n', ''),
array ('production_who1', 'n', ''),
array ('production_who_sure1', 'n', ''),
array ('production_where1', 'n', ''),
array ('production_where_sure1', 'n', ''),
array ('production_annotation1', 'n', ''),
array ('production_when2', 'n', ''),
array ('production_when_sure2', 'n', ''),
array ('production_who2', 'n', ''),
array ('production_who_sure2', 'n', ''),
array ('production_where2', 'n', ''),
array ('production_where_sure2', 'n', ''),
array ('production_annotation2', 'n', ''),
array ('finding_when1', 'n', ''),
array ('finding_when_sure1', 'n', ''),
array ('finding_who1', 'n', ''),
array ('finding_who_sure1', 'n', ''),
array ('finding_where1', 'n', ''),
array ('finding_where_sure1', 'n', ''),
array ('finding_annotation1', 'n', ''),
array ('finding_when2', 'n', ''),
array ('finding_when_sure2', 'n', ''),
array ('finding_who2', 'n', ''),
array ('finding_who_sure2', 'n', ''),
array ('finding_where2', 'n', ''),
array ('finding_where_sure2', 'n', ''),
array ('finding_annotation2', 'n', ''),
array ('publication_when1', 'n', ''),
array ('publication_when_sure1', 'n', ''),
array ('publication_who1', 'n', ''),
array ('publication_who_sure1', 'n', ''),
array ('publication_where1', 'n', ''),
array ('publication_where_sure1', 'n', ''),
array ('publication_annotation1', 'n', ''),
array ('publication_when2', 'n', ''),
array ('publication_when_sure2', 'n', ''),
array ('publication_who2', 'n', ''),
array ('publication_who_sure2', 'n', ''),
array ('publication_where2', 'n', ''),
array ('publication_where_sure2', 'n', ''),
array ('publication_annotation2', 'n', ''),
array ('template_creation_when1', 'n', ''),
array ('template_creation_when_sure1', 'n', ''),
array ('template_creation_who1', 'n', ''),
array ('template_creation_who_sure1', 'n', ''),
array ('template_creation_where1', 'n', ''),
array ('template_creation_where_sure1', 'n', ''),
array ('template_creation_annotation1', 'n', ''),
array ('template_creation_when2', 'n', ''),
array ('template_creation_when_sure2', 'n', ''),
array ('template_creation_who2', 'n', ''),
array ('template_creation_who_sure2', 'n', ''),
array ('template_creation_where2', 'n', ''),
array ('template_creation_where_sure2', 'n', ''),
array ('template_creation_annotation2', 'n', ''),
array ('was_depicted_who1', 'n', ''),
array ('was_depicted_who_sure1', 'n', ''),
array ('was_depicted_who2', 'n', ''),
array ('was_depicted_who_sure2', 'n', ''),
array ('was_depicted_place1', 'n', ''),
array ('was_depicted_place_sure1', 'n', ''),
array ('was_depicted_place2', 'n', ''),
array ('was_depicted_place_sure2', 'n', ''),
array ('was_used_when1', 'n', ''),
array ('was_used_when_sure1', 'n', ''),
array ('was_used_who1', 'n', ''),
array ('was_used_who_sure1', 'n', ''),
array ('was_used_where1', 'n', ''),
array ('was_used_where_sure1', 'n', ''),
array ('was_used_annotation1', 'n', ''),
array ('was_used_when2', 'n', ''),
array ('was_used_when_sure2', 'n', ''),
array ('was_used_who2', 'n', ''),
array ('was_used_who_sure2', 'n', ''),
array ('was_used_where2', 'n', ''),
array ('was_used_where_sure2', 'n', ''),
array ('was_used_annotation2', 'n', ''),
array ('written_when1', 'n', ''),
array ('written_when_sure1', 'n', ''),
array ('written_who1', 'n', ''),
array ('written_who_sure1', 'n', ''),
array ('written_where1', 'n', ''),
array ('written_where_sure1', 'n', ''),
array ('written_annotation1', 'n', ''),
array ('written_when2', 'n', ''),
array ('written_when_sure2', 'n', ''),
array ('written_who2', 'n', ''),
array ('written_who_sure2', 'n', ''),
array ('written_where2', 'n', ''),
array ('written_where_sure2', 'n', ''),
array ('written_annotation2', 'n', ''),
array ('collected_when1', 'n', ''),
array ('collected_when_sure1', 'n', ''),
array ('collected_who1', 'n', ''),
array ('collected_who_sure1', 'n', ''),
array ('collected_where1', 'n', ''),
array ('collected_where_sure1', 'n', ''),
array ('collected_annotation1', 'n', ''),
array ('collected_when2', 'n', ''),
array ('collected_when_sure2', 'n', ''),
array ('collected_who2', 'n', ''),
array ('collected_who_sure2', 'n', ''),
array ('collected_where2', 'n', ''),
array ('collected_where_sure2', 'n', ''),
array ('collected_annotation2', 'n', ''),
array ('painted_when1', 'n', ''),
array ('painted_when_sure1', 'n', ''),
array ('painted_who1', 'n', ''),
array ('painted_who_sure1', 'n', ''),
array ('painted_where1', 'n', ''),
array ('painted_where_sure1', 'n', ''),
array ('painted_annotation1', 'n', ''),
array ('painted_when2', 'n', ''),
array ('painted_when_sure2', 'n', ''),
array ('painted_who2', 'n', ''),
array ('painted_who_sure2', 'n', ''),
array ('painted_where2', 'n', ''),
array ('painted_where_sure2', 'n', ''),
array ('painted_annotation2', 'n', ''),
array ('taken_when1', 'n', ''),
array ('taken_when_sure1', 'n', ''),
array ('taken_who1', 'n', ''),
array ('taken_who_sure1', 'n', ''),
array ('taken_where1', 'n', ''),
array ('taken_where_sure1', 'n', ''),
array ('taken_annotation1', 'n', ''),
array ('taken_when2', 'n', ''),
array ('taken_when_sure2', 'n', ''),
array ('taken_who2', 'n', ''),
array ('taken_who_sure2', 'n', ''),
array ('taken_where2', 'n', ''),
array ('taken_where_sure2', 'n', ''),
array ('taken_annotation2', 'n', ''),
array ('received_when1', 'n', ''),
array ('received_when_sure1', 'n', ''),
array ('received_who1', 'n', ''),
array ('received_who_sure1', 'n', ''),
array ('received_where1', 'n', ''),
array ('received_where_sure1', 'n', ''),
array ('received_annotation1', 'n', ''),
array ('received_when2', 'n', ''),
array ('received_when_sure2', 'n', ''),
array ('received_who2', 'n', ''),
array ('received_who_sure2', 'n', ''),
array ('received_where2', 'n', ''),
array ('received_where_sure2', 'n', ''),
array ('received_annotation2', 'n', ''),
array ('printing_plate_produced_when1', 'n', ''),
array ('printing_plate_produced_when_sure1', 'n', ''),
array ('printing_plate_produced_who1', 'n', ''),
array ('printing_plate_produced_who_sure1', 'n', ''),
array ('printing_plate_produced_where1', 'n', ''),
array ('printing_plate_produced_where_sure1', 'n', ''),
array ('printing_plate_produced_annotation1', 'n', ''),
array ('printing_plate_produced_when2', 'n', ''),
array ('printing_plate_produced_when_sure2', 'n', ''),
array ('printing_plate_produced_who2', 'n', ''),
array ('printing_plate_produced_who_sure2', 'n', ''),
array ('printing_plate_produced_where2', 'n', ''),
array ('printing_plate_produced_where_sure2', 'n', ''),
array ('printing_plate_produced_annotation2', 'n', ''),
array ('sent_when1', 'n', ''),
array ('sent_when_sure1', 'n', ''),
array ('sent_who1', 'n', ''),
array ('sent_who_sure1', 'n', ''),
array ('sent_where1', 'n', ''),
array ('sent_where_sure1', 'n', ''),
array ('sent_annotation1', 'n', ''),
array ('sent_when2', 'n', ''),
array ('sent_when_sure2', 'n', ''),
array ('sent_who2', 'n', ''),
array ('sent_who_sure2', 'n', ''),
array ('sent_where2', 'n', ''),
array ('sent_where_sure2', 'n', ''),
array ('sent_annotation2', 'n', ''),
array ('issued_when1', 'n', ''),
array ('issued_when_sure1', 'n', ''),
array ('issued_who1', 'n', ''),
array ('issued_who_sure1', 'n', ''),
array ('issued_where1', 'n', ''),
array ('issued_where_sure1', 'n', ''),
array ('issued_annotation1', 'n', ''),
array ('issued_when2', 'n', ''),
array ('issued_when_sure2', 'n', ''),
array ('issued_who2', 'n', ''),
array ('issued_who_sure2', 'n', ''),
array ('issued_where2', 'n', ''),
array ('issued_where_sure2', 'n', ''),
array ('issued_annotation2', 'n', ''),
array ('signed_when1', 'n', ''),
array ('signed_when_sure1', 'n', ''),
array ('signed_who1', 'n', ''),
array ('signed_who_sure1', 'n', ''),
array ('signed_where1', 'n', ''),
array ('signed_where_sure1', 'n', ''),
array ('signed_annotation1', 'n', ''),
array ('signed_when2', 'n', ''),
array ('signed_when_sure2', 'n', ''),
array ('signed_who2', 'n', ''),
array ('signed_who_sure2', 'n', ''),
array ('signed_where2', 'n', ''),
array ('signed_where_sure2', 'n', ''),
array ('signed_annotation2', 'n', ''),
array ('type_described_when1', 'n', ''),
array ('type_described_when_sure1', 'n', ''),
array ('type_described_who1', 'n', ''),
array ('type_described_who_sure1', 'n', ''),
array ('type_described_where1', 'n', ''),
array ('type_described_where_sure1', 'n', ''),
array ('type_described_annotation1', 'n', ''),
array ('type_described_when2', 'n', ''),
array ('type_described_when_sure2', 'n', ''),
array ('type_described_who2', 'n', ''),
array ('type_described_who_sure2', 'n', ''),
array ('type_described_where2', 'n', ''),
array ('type_described_where_sure2', 'n', ''),
array ('type_described_annotation2', 'n', ''),
array ('drawn_when1', 'n', ''),
array ('drawn_when_sure1', 'n', ''),
array ('drawn_who1', 'n', ''),
array ('drawn_who_sure1', 'n', ''),
array ('drawn_where1', 'n', ''),
array ('drawn_where_sure1', 'n', ''),
array ('drawn_annotation1', 'n', ''),
array ('drawn_when2', 'n', ''),
array ('drawn_when_sure2', 'n', ''),
array ('drawn_who2', 'n', ''),
array ('drawn_who_sure2', 'n', ''),
array ('drawn_where2', 'n', ''),
array ('drawn_where_sure2', 'n', ''),
array ('drawn_annotation2', 'n', ''),
array ('copied_when1', 'n', ''),
array ('copied_when_sure1', 'n', ''),
array ('copied_who1', 'n', ''),
array ('copied_who_sure1', 'n', ''),
array ('copied_where1', 'n', ''),
array ('copied_where_sure1', 'n', ''),
array ('copied_annotation1', 'n', ''),
array ('copied_when2', 'n', ''),
array ('copied_when_sure2', 'n', ''),
array ('copied_who2', 'n', ''),
array ('copied_who_sure2', 'n', ''),
array ('copied_where2', 'n', ''),
array ('copied_where_sure2', 'n', ''),
array ('copied_annotation2', 'n', ''),
array ('has_lived_when1', 'n', ''),
array ('has_lived_when_sure1', 'n', ''),
array ('has_lived_where1', 'n', ''),
array ('has_lived_where_sure1', 'n', ''),
array ('has_lived_annotation1', 'n', ''),
array ('has_lived_when2', 'n', ''),
array ('has_lived_when_sure2', 'n', ''),
array ('has_lived_where2', 'n', ''),
array ('has_lived_where_sure2', 'n', ''),
array ('has_lived_annotation2', 'n', ''),
array ('commissioned_when1', 'n', ''),
array ('commissioned_when_sure1', 'n', ''),
array ('commissioned_who1', 'n', ''),
array ('commissioned_who_sure1', 'n', ''),
array ('commissioned_where1', 'n', ''),
array ('commissioned_where_sure1', 'n', ''),
array ('commissioned_annotation1', 'n', ''),
array ('commissioned_when2', 'n', ''),
array ('commissioned_when_sure2', 'n', ''),
array ('commissioned_who2', 'n', ''),
array ('commissioned_who_sure2', 'n', ''),
array ('commissioned_where2', 'n', ''),
array ('commissioned_where_sure2', 'n', ''),
array ('commissioned_annotation2', 'n', ''),
array ('printed_when1', 'n', ''),
array ('printed_when_sure1', 'n', ''),
array ('printed_who1', 'n', ''),
array ('printed_who_sure1', 'n', ''),
array ('printed_where1', 'n', ''),
array ('printed_where_sure1', 'n', ''),
array ('printed_annotation1', 'n', ''),
array ('printed_when2', 'n', ''),
array ('printed_when_sure2', 'n', ''),
array ('printed_who2', 'n', ''),
array ('printed_who_sure2', 'n', ''),
array ('printed_where2', 'n', ''),
array ('printed_where_sure2', 'n', ''),
array ('printed_annotation2', 'n', ''),
array ('spoken_when1', 'n', ''),
array ('spoken_when_sure1', 'n', ''),
array ('spoken_who1', 'n', ''),
array ('spoken_who_sure1', 'n', ''),
array ('spoken_where1', 'n', ''),
array ('spoken_where_sure1', 'n', ''),
array ('spoken_annotation1', 'n', ''),
array ('spoken_when2', 'n', ''),
array ('spoken_when_sure2', 'n', ''),
array ('spoken_who2', 'n', ''),
array ('spoken_who_sure2', 'n', ''),
array ('spoken_where2', 'n', ''),
array ('spoken_where_sure2', 'n', ''),
array ('spoken_annotation2', 'n', ''),
array ('sung_when1', 'n', ''),
array ('sung_when_sure1', 'n', ''),
array ('sung_who1', 'n', ''),
array ('sung_who_sure1', 'n', ''),
array ('sung_where1', 'n', ''),
array ('sung_where_sure1', 'n', ''),
array ('sung_annotation1', 'n', ''),
array ('sung_when2', 'n', ''),
array ('sung_when_sure2', 'n', ''),
array ('sung_who2', 'n', ''),
array ('sung_who_sure2', 'n', ''),
array ('sung_where2', 'n', ''),
array ('sung_where_sure2', 'n', ''),
array ('sung_annotation2', 'n', ''),
array ('decor_designed_when1', 'n', ''),
array ('decor_designed_when_sure1', 'n', ''),
array ('decor_designed_who1', 'n', ''),
array ('decor_designed_who_sure1', 'n', ''),
array ('decor_designed_where1', 'n', ''),
array ('decor_designed_where_sure1', 'n', ''),
array ('decor_designed_annotation1', 'n', ''),
array ('decor_designed_when2', 'n', ''),
array ('decor_designed_when_sure2', 'n', ''),
array ('decor_designed_who2', 'n', ''),
array ('decor_designed_who_sure2', 'n', ''),
array ('decor_designed_where2', 'n', ''),
array ('decor_designed_where_sure2', 'n', ''),
array ('decor_designed_annotation2', 'n', ''),
array ('form_designed_when1', 'n', ''),
array ('form_designed_when_sure1', 'n', ''),
array ('form_designed_who1', 'n', ''),
array ('form_designed_who_sure1', 'n', ''),
array ('form_designed_where1', 'n', ''),
array ('form_designed_where_sure1', 'n', ''),
array ('form_designed_annotation1', 'n', ''),
array ('form_designed_when2', 'n', ''),
array ('form_designed_when_sure2', 'n', ''),
array ('form_designed_who2', 'n', ''),
array ('form_designed_who_sure2', 'n', ''),
array ('form_designed_where2', 'n', ''),
array ('form_designed_where_sure2', 'n', ''),
array ('form_designed_annotation2', 'n', ''),
array ('modelled_when1', 'n', ''),
array ('modelled_when_sure1', 'n', ''),
array ('modelled_who1', 'n', ''),
array ('modelled_who_sure1', 'n', ''),
array ('modelled_where1', 'n', ''),
array ('modelled_where_sure1', 'n', ''),
array ('modelled_annotation1', 'n', ''),
array ('modelled_when2', 'n', ''),
array ('modelled_when_sure2', 'n', ''),
array ('modelled_who2', 'n', ''),
array ('modelled_who_sure2', 'n', ''),
array ('modelled_where2', 'n', ''),
array ('modelled_where_sure2', 'n', ''),
array ('modelled_annotation2', 'n', ''),
array ('signed_when1', 'n', ''),
array ('signed_when_sure1', 'n', ''),
array ('signed_who1', 'n', ''),
array ('signed_who_sure1', 'n', ''),
array ('signed_where1', 'n', ''),
array ('signed_where_sure1', 'n', ''),
array ('signed_annotation1', 'n', ''),
array ('signed_when2', 'n', ''),
array ('signed_when_sure2', 'n', ''),
array ('signed_who2', 'n', ''),
array ('signed_who_sure2', 'n', ''),
array ('signed_where2', 'n', ''),
array ('signed_where_sure2', 'n', ''),
array ('signed_annotation2', 'n', ''),
array ('was_mentioned_when1', 'n', ''),
array ('was_mentioned_when_sure1', 'n', ''),
array ('was_mentioned_who1', 'n', ''),
array ('was_mentioned_who_sure1', 'n', ''),
array ('was_mentioned_where1', 'n', ''),
array ('was_mentioned_where_sure1', 'n', ''),
array ('was_mentioned_annotation1', 'n', ''),
array ('was_mentioned_when2', 'n', ''),
array ('was_mentioned_when_sure2', 'n', ''),
array ('was_mentioned_who2', 'n', ''),
array ('was_mentioned_who_sure2', 'n', ''),
array ('was_mentioned_where2', 'n', ''),
array ('was_mentioned_where_sure2', 'n', ''),
array ('was_mentioned_annotation2', 'n', ''),
array ('buried_when1', 'n', ''),
array ('buried_when_sure1', 'n', ''),
array ('buried_who1', 'n', ''),
array ('buried_who_sure1', 'n', ''),
array ('buried_where1', 'n', ''),
array ('buried_where_sure1', 'n', ''),
array ('buried_annotation1', 'n', ''),
array ('buried_when2', 'n', ''),
array ('buried_when_sure2', 'n', ''),
array ('buried_who2', 'n', ''),
array ('buried_who_sure2', 'n', ''),
array ('buried_where2', 'n', ''),
array ('buried_where_sure2', 'n', ''),
array ('buried_annotation2', 'n', ''),
array ('intellectual_creation_when1', 'n', ''),
array ('intellectual_creation_when_sure1', 'n', ''),
array ('intellectual_creation_who1', 'n', ''),
array ('intellectual_creation_who_sure1', 'n', ''),
array ('intellectual_creation_where1', 'n', ''),
array ('intellectual_creation_where_sure1', 'n', ''),
array ('intellectual_creation_annotation1', 'n', ''),
array ('intellectual_creation_when2', 'n', ''),
array ('intellectual_creation_when_sure2', 'n', ''),
array ('intellectual_creation_who2', 'n', ''),
array ('intellectual_creation_who_sure2', 'n', ''),
array ('intellectual_creation_where2', 'n', ''),
array ('intellectual_creation_where_sure2', 'n', ''),
array ('intellectual_creation_annotation2', 'n', ''),
array ('painted_on_when1', 'n', ''),
array ('painted_on_when_sure1', 'n', ''),
array ('painted_on_who1', 'n', ''),
array ('painted_on_who_sure1', 'n', ''),
array ('painted_on_where1', 'n', ''),
array ('painted_on_where_sure1', 'n', ''),
array ('painted_on_annotation1', 'n', ''),
array ('painted_on_when2', 'n', ''),
array ('painted_on_when_sure2', 'n', ''),
array ('painted_on_who2', 'n', ''),
array ('painted_on_who_sure2', 'n', ''),
array ('painted_on_where2', 'n', ''),
array ('painted_on_where_sure2', 'n', ''),
array ('painted_on_annotation2', 'n', ''),
array ('illustrated_when1', 'n', ''),
array ('illustrated_when_sure1', 'n', ''),
array ('illustrated_who1', 'n', ''),
array ('illustrated_who_sure1', 'n', ''),
array ('illustrated_where1', 'n', ''),
array ('illustrated_where_sure1', 'n', ''),
array ('illustrated_annotation1', 'n', ''),
array ('illustrated_when2', 'n', ''),
array ('illustrated_when_sure2', 'n', ''),
array ('illustrated_who2', 'n', ''),
array ('illustrated_who_sure2', 'n', ''),
array ('illustrated_where2', 'n', ''),
array ('illustrated_where_sure2', 'n', ''),
array ('illustrated_annotation2', 'n', ''),
);


